=== modified file 'NEWS'
--- NEWS	2007-09-25 20:19:21 +0000
+++ NEWS	2007-09-25 21:28:01 +0000
@@ -295,6 +295,10 @@
       changed or deleted, and are copied into the checkout when it is 
       updated.  (Martin Pool, #93856, #93860)
 
+   * Print a warning instead of aborting the ``python setup.py install``
+     process if building of a C extension is not possible.
+     (Lukáš Lalinský, Alexander Belchenko)
+
   IMPROVEMENTS:
 
    * Add the option "--show-diff" to the commit command in order to display

=== modified file 'setup.py'
--- setup.py	2007-09-04 09:10:35 +0000
+++ setup.py	2007-09-15 05:13:00 +0000
@@ -149,6 +149,8 @@
 
 command_classes = {'install_scripts': my_install_scripts,
                    'build': bzr_build}
+from distutils import log
+from distutils.errors import CCompilerError, DistutilsPlatformError
 from distutils.extension import Extension
 ext_modules = []
 try:
@@ -165,8 +167,28 @@
     from distutils.command.build_ext import build_ext
 else:
     have_pyrex = True
+
+
+class build_ext_if_possible(build_ext):
+
+    def run(self):
+        try:
+            build_ext.run(self)
+        except DistutilsPlatformError, e:
+            log.warn(str(e))
+            log.warn('Extensions cannot be built, '
+                     'will use the Python versions instead')
+
+    def build_extension(self, ext):
+        try:
+            build_ext.build_extension(self, ext)
+        except CCompilerError:
+            log.warn('Building of "%s" extension failed, '
+                     'will use the Python version instead' % (ext.name,))
+
+
 # Override the build_ext if we have Pyrex available
-command_classes['build_ext'] = build_ext
+command_classes['build_ext'] = build_ext_if_possible
 unavailable_files = []
 
 
@@ -230,7 +252,7 @@
             # help pages
             'data_files': find_docs(),
             # for building pyrex extensions
-            'cmdclass': {'build_ext': build_ext},
+            'cmdclass': {'build_ext': build_ext_if_possible},
            }
 
     ARGS.update(META_INFO)

